utils::globalVariables(
  c("processed", "Gene", "Counts", "metric", "score", "original",
    "scaled_score", "gene", "cluster", "mean_expression", "Avg_exp")
)
